@@ -22,11 +22,12 @@
 #include "appearance-config-tab.h"
 
 #include <KTabWidget>
-#include <KTp/ChatWindowStyleManager>
-#include <KTp/ChatWindowStyle>
-#include <KTp/AdiumThemeHeaderInfo>
-#include <KTp/AdiumThemeContentInfo>
-#include <KTp/AdiumThemeStatusInfo>
+
+#include "chat-window-style-manager.h"
+#include "chat-window-style.h"
+#include "adium-theme-header-info.h"
+#include "adium-theme-content-info.h"
+#include "adium-theme-status-info.h"
 
 #include <KDebug>
 #include <KLocalizedString>
@@ -85,4 +86,6 @@ void AppearanceConfig::save()
     config->sync();
 
     KCModule::save();
+
+    Q_EMIT reloadTheme();
 }
