@@ -24,6 +24,8 @@
 class AdiumThemeHeaderInfoPrivate
 {
 public:
+    explicit AdiumThemeHeaderInfoPrivate();
+
     QString chatName;
     QString sourceName;
     QString destinationName;
@@ -35,6 +37,11 @@ public:
     bool isGroupChat;
 };
 
+AdiumThemeHeaderInfoPrivate::AdiumThemeHeaderInfoPrivate():
+    isGroupChat(false)
+{
+}
+
 AdiumThemeHeaderInfo::AdiumThemeHeaderInfo()
     : d(new AdiumThemeHeaderInfoPrivate)
 {
