@@ -44,15 +44,16 @@ public:
 
     void setTextChannel(const Tp::TextChannelPtr &channel);
 
+    bool containsNick(const QString &nick);
+
+    int rowCount(const QModelIndex &parent = QModelIndex()) const;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+
 Q_SIGNALS:
     void contactPresenceChanged(const Tp::ContactPtr &contact, const KTp::Presence &presence);
     void contactAliasChanged(const Tp::ContactPtr &contact, const QString &alias);
     void contactBlockStatusChanged(const Tp::ContactPtr &contact, bool blocked);
 
-protected:
-    int rowCount(const QModelIndex &parent) const;
-    QVariant data(const QModelIndex &index, int role) const;
-
 private Q_SLOTS:
     void onGroupMembersChanged(const Tp::Contacts &groupMembersAdded,
                              const Tp::Contacts &groupLocalPendingMembersAdded,
@@ -62,8 +63,11 @@ private Q_SLOTS:
     void onContactPresenceChanged(const Tp::Presence &presence);
     void onContactAliasChanged(const QString &alias);
     void onContactBlockStatusChanged(bool blocked);
+    void onChatStateChanged(const Tp::ContactPtr &contact, Tp::ChannelChatState state);
+
 
 private:
+    Tp::TextChannelPtr m_channel;
     void addContacts(const Tp::Contacts &contacts);
     void removeContacts(const Tp::Contacts &contacts);
     QList<Tp::ContactPtr> m_contacts;
