@@ -99,16 +99,19 @@ public:
     QString getTemplateHtml() const;
     QString getHeaderHtml() const;
     QString getFooterHtml() const;
-    QString getIncomingHtml() const;
-    QString getNextIncomingHtml() const;
-    QString getOutgoingHtml() const;
-    QString getNextOutgoingHtml() const;
+    QString getTopicHtml() const;
+
+    QString getIncomingContentHtml() const;
+    QString getIncomingNextContentHtml() const;
+    QString getOutgoingContentHtml() const;
+    QString getOutgoingNextContentHtml() const;
     QString getStatusHtml() const;
 
-    QString getHistoryIncomingHtml() const;
-    QString getHistoryNextIncomingHtml() const;
-    QString getHistoryOutgoingHtml() const;
-    QString getHistoryNextOutgoingHtml() const;
+    QString getIncomingHistoryHtml() const;
+    QString getIncomingNextHistoryHtml() const;
+    QString getOutgoingHistoryHtml() const;
+    QString getOutgoingNextHistoryHtml() const;
+    QString getStatusHistoryHtml() const;
 
     QString getActionIncomingHtml() const;
     QString getActionOutgoingHtml() const;
@@ -122,6 +125,11 @@ public:
     QString getOutgoingStateErrorHtml() const;
     QString getOutgoingStateUnknownHtml() const;
 
+    /**
+     * Check if the style is using a custom Template.html file
+     */
+    bool hasCustomTemplateHtml() const;
+
     /**
      * Check if the style has the support for Kopete Action template (Kopete extension)
      * @return true if the style has Action template.
@@ -144,9 +152,11 @@ public:
      */
     void reload();
 
-    QString defaultVariantName();
-    QString defaultFontFamily();
-    int defaultFontSize();
+    QString defaultVariantName() const;
+    QString defaultFontFamily() const;
+    int defaultFontSize() const;
+    bool disableCombineConsecutive() const;
+    int messageViewVersion() const;
 private:
     /**
      * Read style HTML files from disk
@@ -167,19 +177,30 @@ private:
         Template,
 
         Header,
-        Content,
         Footer,
+        Topic,
 
-        Incoming,
-        IncomingNext,
-        Outgoing,
-        OutgoingNext,
+        Content,
+        NextContent,
+        History,
+        NextHistory,
         Status,
 
-        HistoryIncoming,
-        HistoryIncomingNext,
-        HistoryOutgoing,
-        HistoryOutgoingNext,
+        IncomingContent,
+        IncomingNextContent,
+        IncomingContext,
+        IncomingNextContext,
+        IncomingHistory,
+        IncomingNextHistory,
+
+        OutgoingContent,
+        OutgoingNextContent,
+        OutgoingContext,
+        OutgoingNextContext,
+        OutgoingHistory,
+        OutgoingNextHistory,
+
+        StatusHistory,
 
         ActionIncoming,
         ActionOutgoing,
