@@ -48,7 +48,7 @@ void EntityView::rowsInserted(const QModelIndex &parent, int start, int end)
         const QString selectedPersonaId = KCmdLineArgs::parsedArgs()->arg(0);
         for (int i = start; i <= end; i++) {
             const QModelIndex index = model()->index(i, 0, parent);
-            if (index.data(KTp::NepomukUriRole).toUrl() == selectedPersonaId) {
+            if (index.data(KTp::PersonIdRole).toUrl() == selectedPersonaId) {
                 selectedIndex = index;
                 break;
             }
